[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# IRN Meetings client library for Python

[![API Version](https://img.shields.io/badge/api-v1.4.0-blue)](https://developer.factset.com/api-catalog/irn-meetings-api#apiDocumentation)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.IRNMeetings)](https://pypi.org/project/fds.sdk.IRNMeetings/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Allows users to extract, create, update and configure IRN data.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.4.0
- SDK version: 2.0.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.IRNMeetings==2.0.1
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.IRNMeetings==2.0.1
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.IRNMeetings
from fds.sdk.IRNMeetings.api import attachments_api
from fds.sdk.IRNMeetings.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.IRNMeetings.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.IRNMeetings.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.IRNMeetings.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = attachments_api.AttachmentsApi(api_client)
    meeting_id = "meetingId_example" # str | Meeting Id
    file = open('/path/to/file', 'rb') # file_type | 

    try:
        # Create an attachment for a existing meeting
        # example passing only required values which don't have defaults set
        api_response = api_instance.create_attachment(meeting_id, file)

        pprint(api_response)
    except fds.sdk.IRNMeetings.ApiException as e:
        print("Exception when calling AttachmentsApi->create_attachment: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Create an attachment for a existing meeting
    #     api_response, http_status_code, response_headers = api_instance.create_attachment_with_http_info(meeting_id, file)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IRNMeetings.ApiException as e:
    #     print("Exception when calling AttachmentsApi->create_attachment: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Create an attachment for a existing meeting
    #     async_result = api_instance.create_attachment_async(meeting_id, file)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.IRNMeetings.ApiException as e:
    #     print("Exception when calling AttachmentsApi->create_attachment: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Create an attachment for a existing meeting
    #     async_result = api_instance.create_attachment_with_http_info_async(meeting_id, file)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.IRNMeetings.ApiException as e:
    #     print("Exception when calling AttachmentsApi->create_attachment: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.IRNMeetings

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.IRNMeetings.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.IRNMeetings

configuration = fds.sdk.IRNMeetings.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.IRNMeetings

configuration = fds.sdk.IRNMeetings.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.IRNMeetings

configuration = fds.sdk.IRNMeetings.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/research/irn/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttachmentsApi* | [**create_attachment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttachmentsApi.md#create_attachment) | **POST** /meetings/{meetingId}/attachments | Create an attachment for a existing meeting
*AttachmentsApi* | [**download_attachment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttachmentsApi.md#download_attachment) | **GET** /meetings/{meetingId}/attachments/{attachmentId}/download | Download an attachment from a Meeting
*AttachmentsApi* | [**get_attachments**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttachmentsApi.md#get_attachments) | **GET** /meetings/{meetingId}/attachments | Get all the attachments belonging to a meeting
*AttachmentsApi* | [**soft_delete_meeting_attachment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttachmentsApi.md#soft_delete_meeting_attachment) | **DELETE** /meetings/{meetingId}/attachments/{attachmentId} | Delete attachment from meeting
*CommentsApi* | [**create_comment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#create_comment) | **POST** /meetings/{meetingId}/comments | Create a comment to a Meeting
*CommentsApi* | [**create_comment_attachment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#create_comment_attachment) | **POST** /meetings/{meetingId}/comments/{commentId}/attachments | Create a comment attachment to a Meeting
*CommentsApi* | [**delete_comment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#delete_comment) | **DELETE** /meetings/{meetingId}/comments/{commentId} | Delete a Comment from a Meeting
*CommentsApi* | [**download_comment_attachment_for_comment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#download_comment_attachment_for_comment) | **GET** /meetings/{meetingId}/comments/{commentId}/attachments/{attachmentId}/download | Download single attachment detail of a comment belonging to a meeting
*CommentsApi* | [**get_comment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#get_comment) | **GET** /meetings/{meetingId}/comments/{commentId} | Get details of a comment belonging to a meeting
*CommentsApi* | [**get_comment_attachments**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#get_comment_attachments) | **GET** /meetings/{meetingId}/comments/{commentId}/attachments | Get attachments summary of a comment belonging to a meeting
*CommentsApi* | [**get_comments**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#get_comments) | **GET** /meetings/{meetingId}/comments | Get all comments for a meeting
*CommentsApi* | [**patch_comment**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentsApi.md#patch_comment) | **PATCH** /meetings/{meetingId}/comments/{commentId} | Edit a comment for a meeting
*EventsApi* | [**get_events**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/EventsApi.md#get_events) | **GET** /meetings/{meetingId}/events | Get all the record events that belong to a meeting
*EventsApi* | [**get_record_event**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/EventsApi.md#get_record_event) | **GET** /meetings/{meetingId}/events/{recordEventId} | Get details of a record event of a meeting
*MeetingsApi* | [**create_meeting**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingsApi.md#create_meeting) | **POST** /meetings | Create a meeting
*MeetingsApi* | [**delete_meeting**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingsApi.md#delete_meeting) | **DELETE** /meetings/{meetingId} | Delete a Meeting
*MeetingsApi* | [**get_meeting**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingsApi.md#get_meeting) | **GET** /meetings/{meetingId} | Get details of a meeting
*MeetingsApi* | [**get_meetings**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingsApi.md#get_meetings) | **GET** /meetings | Get all the meetings in the specified date range filtered on the given identifiers
*MeetingsApi* | [**update_meeting**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingsApi.md#update_meeting) | **PUT** /meetings/{meetingId} | Update meeting


## Documentation For Models

 - [AttachmentSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttachmentSummaryDto.md)
 - [AttendeeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/AttendeeDto.md)
 - [CommentDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentDto.md)
 - [CommentSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CommentSummaryDto.md)
 - [CreateBodyDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CreateBodyDto.md)
 - [CreateCommentDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CreateCommentDto.md)
 - [CreateCustomFieldValueDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CreateCustomFieldValueDto.md)
 - [CreateMeetingDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CreateMeetingDto.md)
 - [CustomFieldValueDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/CustomFieldValueDto.md)
 - [LocationDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/LocationDto.md)
 - [MeetingDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingDto.md)
 - [MeetingEventDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingEventDto.md)
 - [MeetingSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/MeetingSummaryDto.md)
 - [NewItemDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/NewItemDto.md)
 - [Operation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/Operation.md)
 - [OperationType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/OperationType.md)
 - [ProblemDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/ProblemDetails.md)
 - [RecordChangeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/RecordChangeDto.md)
 - [RecordEventSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/RecordEventSummaryDto.md)
 - [ReferenceAttendeeDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/ReferenceAttendeeDto.md)
 - [RelatedRecordsDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/RelatedRecordsDto.md)
 - [SubcommentSummaryDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/SubcommentSummaryDto.md)
 - [UpdateMeetingDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/UpdateMeetingDto.md)
 - [UserSerialDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/UserSerialDto.md)
 - [UserTeamLookupDto](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/IRNMeetings/v1/docs/UserTeamLookupDto.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.IRNMeetings.apis and fds.sdk.IRNMeetings.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.IRNMeetings.api.default_api import DefaultApi`
- `from fds.sdk.IRNMeetings.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.IRNMeetings
from fds.sdk.IRNMeetings.apis import *
from fds.sdk.IRNMeetings.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

